h-card parsing tests

# h-card parsing tests ‐ change logs

The files in this directory where designed to test the parsing of h-card.

## Change log:

- Correct errors in output impliedname.json ‐ 30 April 2020 by Jason Garber
- Update hyperlinkedphoto.json output to reflect the parsing rules for src and alt attributes on img elements ‐ 30 April 2020 by Jason Garber
- Update JSON output to reflect the parsing rules for src and alt attributes on img elements ‐ 29 April 2020 by Jason Garber
- Updated JSON in order to reflect the parsing rules for src and alt attributes on img elements ‐ 24 June 2019 by Jan Sauer
- Added test for empty href="" attribute in implied property ‐ 3 June 2017 by Sven Knebel
- Added test using empty href="" attribute to reference current page ‐ 27 May 2017 by Sven Knebel
- Changed the order of items in type property for nested tests ‐ 23 May 2015 by Glenn Jones
- Remove duplicate structures from items[] in horghcard and nested tests ‐ 23 May 2015 by Glenn Jones
- Broke old HTML format into small files to aid simpler testing ‐ 21 May 2015 by Glenn Jones
- Updated JSON examples so it always has the rel={} object as well as the items=[] array ‐ 21 November 2013 by Glenn Jones
- Added single child implied test ‐ 6 February 2013 by Glenn Jones
- Added p-proprety test ‐ 6 January 2013 by Glenn Jones
- Reordered JSON ‐ 22 December 2012 by Glenn Jones
- Corrected JSON ‐ 18 December 2012 by Glenn Jones
- Updated format ‐ 22 November 2012 by Glenn Jones
- Updated format ‐ 21 November 2012 by Glenn Jones
- Created ‐ 10 September 2012 by Glenn Jones

## Contributors:

- Tantek Çelik
- Glenn Jones
- Sven Knebel
- Jan Sauer